==> ure-0.2.0.tgz: package/es/index.js <==
import chunk from './chunk.js';
import remove from './remove.js';
import removeIndex from './removeIndex.js';
import random from './random.js';
import shuffle from './shuffle.js';
import debounce from './debounce.js';
import ua from './ua.js';
import isAndroid from './isAndroid.js';
import isDingTalk from './isDingTalk.js';
import isEdge from './isEdge.js';
import isIE from './isIE.js';
import isIOS from './isIOS.js';
import isIpad from './isIpad.js';
import isMobile from './isMobile.js';
import isPC from './isPC.js';
import isQQ from './isQQ.js';
import isWeixin from './isWeixin.js';
import throttle from './throttle.js';
import getCookie from './getCookie.js';
import parseCookie from './parseCookie.js';
import setCookie from './setCookie.js';
import getType from './getType.js';
import isEmpty from './isEmpty.js';
import isTypeof from './isTypeof.js';
import inRange from './inRange.js';
import midNumber from './midNumber.js';
import { _ as _typeof } from './internal/_rollupPluginBabelHelpers.js';
import randomColor from './randomColor.js';
import randomKey from './randomKey.js';
import isEmail from './isEmail.js';
import isImage from './isImage.js';
import isNumber from './isNumber.js';
import isPhone from './isPhone.js';
import getUrlParam from './getUrlParam.js';
import './internal/_handleSearch.js';
import parseQuery from './parseQuery.js';
import parseUrl from './parseUrl.js';
import setUrlParam from './setUrlParam.js';

/**
 * 拓展对象
 * @param {Object}
 * @returns Object
 */
var extend = function extend() {
  var _arguments = arguments;
  if (!arguments.length) return {};
  var target = arguments[0];

  var _loop = function _loop(i, len) {
    Object.keys(_arguments[i]).forEach(function (k) {
      target[k] = _arguments[i][k];
    });
  };

  for (var i = 1, len = arguments.length; i < len; ++i) {
    _loop(i);
  }

  return target;
};

/**
 * 浅拷贝
 * @param {Object} target
 */

var clone = function clone(target) {
  if (target == null || _typeof(target) !== 'object') return target;
  return extend({}, target);
};

var forEach = function forEach(target, cb) {
  var len = target.length;
  var i = 0;

  while (i < len) {
    cb(target[i], i++, target);
  }
};
/**
 * 深拷贝 (不拷贝：函数、正则对象、日期对象...)
 * @param {Object} target
 */


var cloneDeep = function cloneDeep(target) {
  // 非对象类型
  if (target === null || _typeof(target) !== 'object' || typeof target === 'function') {
    return target;
  } // 普通对象与数组克隆


  var isArray = Array.isArray(target);
  var list = isArray ? undefined : Object.keys(target);
  var result = isArray ? [] : {};
  forEach(list || target, function (val, key) {
    if (!isArray) {
      key = val;
    }

    result[key] = cloneDeep(target[key]);
  });
  return result;
};

/**
 * 根据路径获取对象中的值
 * @param {Object} target
 * @param {String} path
 * @param {Any} defaultValue
 */
var getValue = function getValue(target, path, defaultValue) {
  if (target === null || target === undefined) return defaultValue;
  var pathList = String.prototype.split.call(path, /[,[\].]+?/).filter(Boolean);
  var result = target;
  var index = 0;

  while (result !== null && result !== undefined && index < pathList.length) {
    result = result[pathList[index]];
    index++;
  }

  return result || defaultValue;
};

/**
 * 批量删除对象中的key值(shallow)
 * @param {Object} target 目标对象
 * @param {String | Array} keys 要删除的key值
 */
var omit = function omit(target, keys) {
  if (!Array.isArray(keys)) {
    if (typeof keys === 'string') {
      keys = keys.split(/[,;\s]/);
    } else {
      return target;
    }
  }

  return Object.keys(target).reduce(function (result, k) {
    if (keys.indexOf(k) === -1) {
      result[k] = target[k];
    }

    return result;
  }, {});
};

/**
 * A isEqual to B
 * @param {Any} left
 * @param {Any} right
 */
var isEqual = function isEqual(left, right) {
  if (_typeof(left) !== _typeof(right)) return false; // both left and right are NaN
  // eslint-disable-next-line no-self-compare

  if (left !== left && right !== right) return true;
  if (_typeof(left) !== 'object' && _typeof(right) !== 'object') return left === right;

  if (Array.isArray(left) && Array.isArray(right)) {
    if (left.length !== right.length) return false;
    return left.every(function (leftItem, index) {
      return isEqual(leftItem, right[index]);
    });
  }

  var leftKeys = Object.keys(left);
  var rightKeys = Object.keys(right);
  if (leftKeys.length !== rightKeys.length) return false;
  return leftKeys.every(function (key) {
    return right.hasOwnProperty(key) && isEqual(left[key], right[key]);
  });
};

var index = {
  ua: ua,
  isMobile: isMobile,
  isPC: isPC,
  isIE: isIE,
  isEdge: isEdge,
  isIOS: isIOS,
  isIpad: isIpad,
  isAndroid: isAndroid,
  isWeixin: isWeixin,
  isQQ: isQQ,
  isDingTalk: isDingTalk,
  debounce: debounce,
  throttle: throttle,
  getType: getType,
  isTypeof: isTypeof,
  isEmpty: isEmpty,
  inRange: inRange,
  midNumber: midNumber,
  extend: extend,
  clone: clone,
  cloneDeep: cloneDeep,
  getValue: getValue,
  omit: omit,
  isEqual: isEqual,
  chunk: chunk,
  remove: remove,
  removeIndex: removeIndex,
  shuffle: shuffle,
  random: random,
  randomColor: randomColor,
  randomKey: randomKey,
  isEmail: isEmail,
  isNumber: isNumber,
  isPhone: isPhone,
  isImage: isImage,
  getCookie: getCookie,
  setCookie: setCookie,
  parseCookie: parseCookie,
  parseUrl: parseUrl,
  parseQuery: parseQuery,
  getUrlParam: getUrlParam,
  setUrlParam: setUrlParam
};

export default index;

==> ure-0.2.4.tgz: package/es/index.js <==
import chunk from './chunk.js';
import remove from './remove.js';
import removeIndex from './removeIndex.js';
import random from './random.js';
import shuffle from './shuffle.js';
import debounce from './debounce.js';
import ua from './ua.js';
import isAndroid from './isAndroid.js';
import isDingTalk from './isDingTalk.js';
import isEdge from './isEdge.js';
import isIE from './isIE.js';
import isIOS from './isIOS.js';
import isIpad from './isIpad.js';
import isMobile from './isMobile.js';
import isPC from './isPC.js';
import isQQ from './isQQ.js';
import isWeixin from './isWeixin.js';
import throttle from './throttle.js';
import getCookie from './getCookie.js';
import parseCookie from './parseCookie.js';
import setCookie from './setCookie.js';
import getType from './getType.js';
import isEmpty from './isEmpty.js';
import isTypeof from './isTypeof.js';
import inRange from './inRange.js';
import midNumber from './midNumber.js';
import './internal/_rollupPluginBabelHelpers.js';
import extend from './extend.js';
import clone from './clone.js';
import cloneDeep from './cloneDeep.js';
import getValue from './getValue.js';
import isEqual from './isEqual.js';
import omit from './omit.js';
import randomColor from './randomColor.js';
import randomKey from './randomKey.js';
import isEmail from './isEmail.js';
import isImage from './isImage.js';
import isNumber from './isNumber.js';
import isPhone from './isPhone.js';
import getUrlParam from './getUrlParam.js';
import './internal/_handleSearch.js';
import parseQuery from './parseQuery.js';
import parseUrl from './parseUrl.js';
import setUrlParam from './setUrlParam.js';

var index = {
  ua: ua,
  isMobile: isMobile,
  isPC: isPC,
  isIE: isIE,
  isEdge: isEdge,
  isIOS: isIOS,
  isIpad: isIpad,
  isAndroid: isAndroid,
  isWeixin: isWeixin,
  isQQ: isQQ,
  isDingTalk: isDingTalk,
  debounce: debounce,
  throttle: throttle,
  getType: getType,
  isTypeof: isTypeof,
  isEmpty: isEmpty,
  inRange: inRange,
  midNumber: midNumber,
  extend: extend,
  clone: clone,
  cloneDeep: cloneDeep,
  getValue: getValue,
  omit: omit,
  isEqual: isEqual,
  chunk: chunk,
  remove: remove,
  removeIndex: removeIndex,
  shuffle: shuffle,
  random: random,
  randomColor: randomColor,
  randomKey: randomKey,
  isEmail: isEmail,
  isNumber: isNumber,
  isPhone: isPhone,
  isImage: isImage,
  getCookie: getCookie,
  setCookie: setCookie,
  parseCookie: parseCookie,
  parseUrl: parseUrl,
  parseQuery: parseQuery,
  getUrlParam: getUrlParam,
  setUrlParam: setUrlParam
};

export default index;
